package sun.management.jmxremote;

import sun.misc.ObjectInputFilter;
import java.rmi.AccessException;
import java.rmi.NotBoundException;
import java.rmi.server.RMIServerSocketFactory;
import java.rmi.server.RMIClientSocketFactory;
import java.rmi.RemoteException;
import java.rmi.Remote;
import sun.rmi.registry.RegistryImpl;

public class SingleEntryRegistry extends RegistryImpl
{
    private final String name;
    private final Remote object;
    private static final long serialVersionUID = -4897238949499730950L;
    
    SingleEntryRegistry(int n, String name, Remote object) throws RemoteException {
        super(n, null, null, (sun.misc.ObjectInputFilter<sun.management.jmxremote.SingleEntryRegistry,sun.misc.ObjectInputFilter.Status>)SingleEntryRegistry::singleRegistryFilter);
        this.name = name;
        this.object = object;
    }
    
    SingleEntryRegistry(int n, RMIClientSocketFactory rmiClientSocketFactory, RMIServerSocketFactory rmiServerSocketFactory, String name, Remote object) throws RemoteException {
        super(n, rmiClientSocketFactory, rmiServerSocketFactory, (sun.misc.ObjectInputFilter<sun.management.jmxremote.SingleEntryRegistry,sun.misc.ObjectInputFilter.Status>)SingleEntryRegistry::singleRegistryFilter);
        this.name = name;
        this.object = object;
    }
    
    @Override
    public String[] list() {
        return new String[] { this.name };
    }
    
    @Override
    public Remote lookup(String str) throws NotBoundException {
        if (str.equals(this.name)) {
            return this.object;
        }
        throw new NotBoundException("Not bound: \"" + str + "\" (only bound name is \"" + this.name + "\")");
    }
    
    @Override
    public void bind(String s, Remote remote) throws AccessException {
        throw new AccessException("Cannot modify this registry");
    }
    
    @Override
    public void rebind(String s, Remote remote) throws AccessException {
        throw new AccessException("Cannot modify this registry");
    }
    
    @Override
    public void unbind(String s) throws AccessException {
        throw new AccessException("Cannot modify this registry");
    }
    
    private static ObjectInputFilter.Status singleRegistryFilter(ObjectInputFilter.FilterInfo filterInfo) {
        return (filterInfo.serialClass() != null || filterInfo.depth() > 2L || filterInfo.references() > 4L || filterInfo.arrayLength() >= 0L) ? ObjectInputFilter.Status.REJECTED : ObjectInputFilter.Status.ALLOWED;
    }
}
